@@ -1,4 +1,3 @@
-import handler
-
+from . import handler
 if __name__ == '__main__':
     handler.main()
\ No newline at end of file
